aboutsummaryrefslogtreecommitdiff
path: root/.config/awesome
diff options
context:
space:
mode:
Diffstat (limited to '.config/awesome')
-rw-r--r--.config/awesome/rc.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/.config/awesome/rc.lua b/.config/awesome/rc.lua
index 661f9ac..f540554 100644
--- a/.config/awesome/rc.lua
+++ b/.config/awesome/rc.lua
@@ -241,9 +241,9 @@ awful.screen.connect_for_each_screen(function(s)
}
-- Create the wibox
- s.mywibox = awful.wibar({ position = "top", screen = s, height = 20 })
- -- use `height = 20` for 80 dpi
- -- use `height = 22` for 96 dpi
+ s.mywibox = awful.wibar({ position = "top", screen = s, height = 18 })
+ -- use `height = 18` for 80 dpi
+ -- use `height = 20` for 96 dpi
-- Add widgets to the wibox
s.mywibox:setup {